@@ -7,7 +7,7 @@ def download(build_type='stable'):
     Downloads a vanilla minecraft server binary and returns the contents of
     the download.
     '''
-    if built_type == 'stable':
+    if build_type == 'stable':
         bin_url = 'MinecraftDownload/launcher/minecraft_server.jar?'
         vrex = re.compile(r'Minecraft (\d(?:\.\d{1,3}){1,3})</a>')
         versions = vrex.findall(urlopen('http://mcupdate.tumblr.com/').read())
